import os

from ipapython.platform import base, redhat, fedora18
from ipapython.platform.debian.auth import DebianAuthConfig
from ipapython.platform.debian.service import debian_service, DebianServices

# All what we allow exporting directly from this module
# Everything else is made available through these symbols when they are
# directly imported into ipapython.services:
#
# authconfig -- class reference for platform-specific implementation of
#               authconfig(8)
# service    -- class reference for platform-specific implementation of a
#               PlatformService class
# knownservices -- factory instance to access named services IPA cares about,
#                  names are ipapython.services.wellknownservices
# backup_and_replace_hostname -- platform-specific way to set hostname and
#                                make it persistent over reboots
# restore_network_configuration -- platform-specific way of restoring network
#                                  configuration (e.g. static hostname)
# restore_context -- platform-sepcific way to restore security context, if
#                    applicable
# check_selinux_status -- platform-specific way to see if SELinux is enabled
#                         and restorecon is installed.
__all__ = ['authconfig', 'service', 'knownservices',
    'backup_and_replace_hostname', 'restore_context', 'check_selinux_status',
    'restore_network_configuration', 'timedate_services']

# Just copy a referential list of timedate services
timedate_services = list(base.timedate_services)

def restore_network_configuration(fstore, statestore):
    filepath = '/etc/hostname'
    if fstore.has_file(filepath):
        fstore.restore_file(filepath)
        hostname_was_configured = True

authconfig = DebianAuthConfig
service = debian_service
knownservices = DebianServices()
backup_and_replace_hostname = fedora18.backup_and_replace_hostname
restore_context = redhat.restore_context
check_selinux_status = redhat.check_selinux_status
