import time

from ipapython import ipautil
from ipapython.ipa_log_manager import root_logger
from ipapython.platform import base
from ipalib import api

class DebianService(base.PlatformService):
    def __wait_for_open_ports(self, instance_name=""):
        """
        If this is a service we need to wait for do so.
        """
        ports = None
        if instance_name in base.wellknownports:
            ports = base.wellknownports[instance_name]
        else:
            if self.service_name in base.wellknownports:
                ports = base.wellknownports[self.service_name]
        if ports:
            ipautil.wait_for_open_ports('localhost', ports, api.env.startup_timeout)
    def stop(self, instance_name='', capture_output=True):
        ipautil.run(["/usr/sbin/service", self.service_name, "stop",
                     instance_name], capture_output=capture_output)
        if 'context' in api.env and api.env.context in ['ipactl', 'installer']:
            update_service_list = True
        else:
            update_service_list = False
        super(DebianService, self).stop(instance_name)

    def start(self, instance_name='', capture_output=True, wait=True):
        ipautil.run(["/usr/sbin/service", self.service_name, "start",
                     instance_name], capture_output=capture_output)
        if 'context' in api.env and api.env.context in ['ipactl', 'installer']:
            update_service_list = True
        else:
            update_service_list = False
        if wait and self.is_running(instance_name):
            self.__wait_for_open_ports(instance_name)
        super(DebianService, self).start(instance_name)

    def restart(self, instance_name='', capture_output=True, wait=True):
        ipautil.run(["/usr/sbin/service", self.service_name, "restart",
                     instance_name], capture_output=capture_output)
        if wait and self.is_running(instance_name):
            self.__wait_for_open_ports(instance_name)

    def is_running(self, instance_name=""):
        ret = True
        try:
            (sout, serr, rcode) = ipautil.run(["/usr/sbin/service",
                                              self.service_name, "status",
                                              instance_name])
            if sout.find("NOT running") >= 0:
                ret = False
            if sout.find("stop") >= 0:
                ret = False
        except ipautil.CalledProcessError:
                ret = False
        return ret

    def is_installed(self):
        installed = True
        try:
            ipautil.run(["/usr/sbin/service", self.service_name, "status"])
        except ipautil.CalledProcessError, e:
            if e.returncode == 1:
                # service is not installed or there is other serious issue
                installed = False
        return installed

    def is_enabled(self, instance_name=""):
        # Services are always assumed to be enabled when installed
        return True

    def enable(self):
        return True

    def disable(self):
        return True

    def install(self):
        return True

    def remove(self):
        return True

class DebianSSHService(DebianService):
    def get_config_dir(self, instance_name=""):
        return '/etc/ssh'

def debian_service(name):
    if name == 'sshd':
        return DebianSSHService(name)
    return DebianService(name)

class DebianServices(base.KnownServices):
    def __init__(self):
        services = dict()
        for s in base.wellknownservices:
            if s == "messagebus":
                services[s] = debian_service("dbus")
            elif s == "ntpd":
                services[s] = debian_service("ntp")
            else:
                services[s] = debian_service(s)
        # Call base class constructor. This will lock services to read-only
        super(DebianServices, self).__init__(services)
